Welcome to mirror list, hosted at ThFree Co, Russian Federation.

cygwin.com/git/cygwin-apps/calm.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJon Turney <jon.turney@dronecode.org.uk>2017-01-18 21:10:19 +0300
committerJon Turney <jon.turney@dronecode.org.uk>2017-01-19 15:11:10 +0300
commitc364814640609dea047f8b6908b9da61a7666bd7 (patch)
treea9214ef3daee10cfdeb6c4d76e1785e02a6c882c
parent3a51d190397c1bd52edbc23daf793f4efcec4657 (diff)
Unbreak checking that all package which share a source package have same version
Fix thinkos introduced in 39136ce0 which broke the check that all packages from a source package have the same version. Also revise the exceptions list to list install packages, not source packages
-rwxr-xr-xcalm/package.py14
-rw-r--r--calm/past_mistakes.py46
2 files changed, 31 insertions, 29 deletions
diff --git a/calm/package.py b/calm/package.py
index a40105d..41c97c6 100755
--- a/calm/package.py
+++ b/calm/package.py
@@ -616,13 +616,18 @@ def validate_packages(args, packages):
for install_p in packages[source_p].is_used_by:
# ignore obsolete packages
- if not any(['_obsolete' in packages[p].version_hints[vr]['category'] for vr in packages[p].version_hints]):
+ if any(['_obsolete' in packages[install_p].version_hints[vr]['category'] for vr in packages[install_p].version_hints]):
continue
+
# ignore runtime library packages, as we may keep old versions of
# those
if re.match(r'^lib.*\d', install_p):
continue
+ # ignore specific packages
+ if install_p in past_mistakes.nonunique_versions:
+ continue
+
versions[packages[install_p].best_version].append(install_p)
if len(versions) > 1:
@@ -638,11 +643,8 @@ def validate_packages(args, packages):
out.append("%s (%s)" % (v, ','.join(versions[v])))
most_common = False
- lvl = logging.DEBUG
- if source_p not in past_mistakes.nonunique_versions:
- lvl = logging.ERROR
- error = True
- logging.log(lvl, "install packages from source package '%s' have non-unique current versions %s" % (source_p, ', '.join(reversed(out))))
+ error = True
+ logging.error("install packages from source package '%s' have non-unique current versions %s" % (source_p, ', '.join(reversed(out))))
# validate that all packages are in the package maintainers list
validate_package_maintainers(args, packages)
diff --git a/calm/past_mistakes.py b/calm/past_mistakes.py
index e4acfcb..802ad28 100644
--- a/calm/past_mistakes.py
+++ b/calm/past_mistakes.py
@@ -96,28 +96,28 @@ self_source = [
'tesseract-training-vie',
]
# these are source packages which currently have non-unique install versions
nonunique_versions = [
- 'bzr', # debuginfo from NMU needs to age out?
- 'cgdb', # ditto
- 'e2fsprogs',
- 'fltk',
- 'gnome-panel',
- 'guile',
- 'libical',
- 'libjpeg-turbo', # libturbojpeg isn't detected as an old soversion
- 'librsvg2',
- 'mutter',
- 'ocaml', # ocaml-camlp4 removed from ocaml distribution after 4.01.0
- 'openmpi', # libopenmpi isn't detected as an old soversion
- 'python-openssl', # no debuginfo anymore due to pure python?
- 'python3-openssl', # ditto?
- 'qt5-webkit',
- 'rsync', # debuginfo from NMU needs to age out?
- 'ruby-gdk3',
- 'sng',
- 'socat',
- 'sqlite3', # sqlite3-zlib removed in 3.8.10, use sqlite3-compress instead
- 'w3m',
- 'zlib',
+ 'bzr-debuginfo', # debuginfo from NMU needs to age out
+ 'cgdb-debuginfo', # debuginfo from NMU needs to age out
+ 'gnome-panel-doc',
+ 'gtk2.0-engines-svg',
+ 'guile-doc',
+ 'info', # something went wrong with package build?
+ 'libfltk-doc',
+ 'libical_cxx-devel',
+ 'libquota-devel', # no longer provided by e2fsprogs
+ 'libturbojpeg', # no number means it isn't considered an old soversion
+ 'minizip',
+ 'mutter-doc',
+ 'ocaml-camlp4', # ocaml-camlp4 removed from ocaml distribution after 4.01.0
+ 'python-openssl-debuginfo', # no debuginfo anymore due to pure python
+ 'python3-openssl-debuginfo', # no debuginfo anymore due to pure python
+ 'ruby-gdk3-debuginfo', # no debuginfo anymore due to pure ruby
+ 'sng-debuginfo',
+ 'socat-debuginfo', # debuginfo for test version when curr has no debuginfo
+ 'sqlite3-zlib', # sqlite3-zlib removed in 3.8.10, use sqlite3-compress instead
+ 'texinfo-debuginfo', # something went wrong with package build?
+ 'w3m-img',
]
@@ -96,28 +96,28 @@ self_source = [
'tesseract-training-vie',
]
-# these are source packages which currently have non-unique install versions
+# these are packages which currently have versions different to all the other
+# install packages from the same source package
nonunique_versions = [